aboutsummaryrefslogtreecommitdiffstats
path: root/src/native/ogl/gldefs.h
diff options
context:
space:
mode:
authorChien Yang <[email protected]>2004-10-28 21:22:10 +0000
committerChien Yang <[email protected]>2004-10-28 21:22:10 +0000
commit2ce93668c57e29a6d2ea992f8675afdd0719c820 (patch)
treeb2a42e5956025c0da23bd716dd407c9f15b3baaa /src/native/ogl/gldefs.h
parentcc979689cf50222764a085f775dc39c583add82d (diff)
1) Fixed issue 77 : Scene antialiasing is disabled on Windows / OpenGL
2) For Win32-OGL : Apply similar technique, used in fix to 77, to Stereo, DoubleBuffer and Accum. 3) For Unix and Win32-OGL : Automat multisample density request in chooseFBConfig/ChoosePixelFormat if ARB_multisample is supported. It starts with sample density = 8 and move down if it can't find one. git-svn-id: https://svn.java.net/svn/j3d-core~svn/trunk@63 ba19aa83-45c5-6ac9-afd3-db810772062c
Diffstat (limited to 'src/native/ogl/gldefs.h')
-rw-r--r--src/native/ogl/gldefs.h23
1 files changed, 16 insertions, 7 deletions
diff --git a/src/native/ogl/gldefs.h b/src/native/ogl/gldefs.h
index f5ce5f6..b1fbe7d 100644
--- a/src/native/ogl/gldefs.h
+++ b/src/native/ogl/gldefs.h
@@ -602,16 +602,28 @@ typedef struct {
typedef struct PixelFormatInfoRec PixelFormatInfo;
struct PixelFormatInfoRec {
/* Information about pixel format(s) */
int onScreenPFormat; /* PixelFormat for onScreen */
+ GLboolean onScreenHasMultisample; /* TRUE if WGL_SAMPLE_BUFFERS_ARB is TRUE and
+ WGL_SAMPLES_ARB > 1 */
+ GLboolean onScreenHasStereo;
+ GLboolean onScreenHasDoubleBuffer;
+ GLboolean onScreenHasAccum;
+ /* Information about onScreen pixel format */
int offScreenPFormat; /* PixelFormat for offScreen */
+ GLboolean offScreenHasMultisample; /* TRUE if WGL_SAMPLE_BUFFERS_ARB is TRUE and
+ WGL_SAMPLES_ARB > 1 */
+ GLboolean offScreenHasStereo;
+ GLboolean offScreenHasDoubleBuffer;
+ GLboolean offScreenHasAccum;
GLboolean drawToPbuffer; /* value of DRAW_TO_PBUFFER attr for offScreenPFormat */
-
+
/* Information about extension support */
+ char* supportedExtensions; /* list of supported ARB extensions */
GLboolean supportARB; /* TRUE if wgl*PixelFormat*ARB functions supported */
GLboolean supportPbuffer; /* TRUE if wgl*Pbuffer functions supported */
- char* supportedExtensions; /* list of supported ARB extensions */
-
+
+
/* handle to ARB functions */
PFNWGLCHOOSEPIXELFORMATARBPROC wglChoosePixelFormatARB;
PFNWGLGETPIXELFORMATATTRIBIVARBPROC wglGetPixelFormatAttribivARB;
@@ -620,9 +632,6 @@ struct PixelFormatInfoRec {
PFNWGLRELEASEPBUFFERDCARBPROC wglReleasePbufferDCARB;
PFNWGLDESTROYPBUFFERARBPROC wglDestroyPbufferARB;
PFNWGLQUERYPBUFFERARBPROC wglQueryPbufferARB;
-
- /* TODO include multi-samples buffer */
-
};
#endif /* WIN32 */
@@ -602,16 +602,28 @@ typedef struct {
typedef struct PixelFormatInfoRec PixelFormatInfo;
struct PixelFormatInfoRec {
- /* Information about pixel format(s) */
+ /* Information about onScreen pixel format */
int onScreenPFormat; /* PixelFormat for onScreen */